SQLAlchemy 0.3 Documentation - module sqlalchemy.databases.sqlite

# SQLAlchemy 0.3 Documentation

Multiple Pages | One Page
Version: 0.3.7 Last Updated: 04/30/07 00:08:52

### module sqlalchemy.databases.sqlite

### Module Functions

def descriptor()

### class DateTimeMixin(object)

def convert_bind_param(self, value, dialect)
back to section top

### class PassiveDefault(DefaultGenerator)

A default that takes effect on the database side.

def __init__(self, arg, **kwargs)
def accept_visitor(self, visitor)
back to section top

### class SLBinary(Binary)

def get_col_spec(self)
back to section top

### class SLBoolean(Boolean)

def convert_bind_param(self, value, dialect)
def convert_result_value(self, value, dialect)
def get_col_spec(self)
back to section top

### class SLChar(CHAR)

def get_col_spec(self)
back to section top

### class SLDate(DateTimeMixin,Date)

def convert_result_value(self, value, dialect)
def get_col_spec(self)
back to section top

### class SLDateTime(DateTimeMixin,DateTime)

def convert_result_value(self, value, dialect)
def get_col_spec(self)
back to section top

### class SLInteger(Integer)

def get_col_spec(self)
back to section top

### class SLNumeric(Numeric)

def get_col_spec(self)
back to section top

### class SLSmallInteger(SmallInteger)

def get_col_spec(self)
back to section top

### class SLString(String)

def get_col_spec(self)
back to section top

### class SLText(TEXT)

def get_col_spec(self)
back to section top

### class SLTime(DateTimeMixin,Time)

def convert_result_value(self, value, dialect)
def get_col_spec(self)
back to section top

### class SQLiteCompiler(ANSICompiler)

def binary_operator_string(self, binary)
def for_update_clause(self, select)
def limit_clause(self, select)
def visit_cast(self, cast)
back to section top

### class SQLiteDialect(ANSIDialect)

def __init__(self, **kwargs)
def compiler(self, statement, bindparams, **kwargs)
def create_connect_args(self, url)
def create_execution_context(self, **kwargs)
def dbapi(cls)
def has_table(self, connection, table_name, schema=None)
def last_inserted_ids(self)
def oid_column_name(self, column)
def preparer(self)
def reflecttable(self, connection, table)
def schemadropper(self, *args, **kwargs)
def schemagenerator(self, *args, **kwargs)
def supports_alter(self)
def supports_unicode_statements(self)
def type_descriptor(self, typeobj)
back to section top

### class SQLiteExecutionContext(DefaultExecutionContext)

def post_exec(self)
back to section top

### class SQLiteIdentifierPreparer(ANSIIdentifierPreparer)

def __init__(self, dialect)
back to section top

### class SQLiteSchemaDropper(ANSISchemaDropper)

back to section top

### class SQLiteSchemaGenerator(ANSISchemaGenerator)

def get_column_specification(self, column, **kwargs)
back to section top